@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Settings
- * @version    $Id: 120.system.php 1175 2010-06-28 08:53:41Z d00p $
+ * @version    $Id: 120.system.php 1345 2010-10-16 20:00:24Z d00p $
  */
 
 return array(
@@ -28,6 +28,7 @@ return array(
 					'varname' => 'documentroot_prefix',
 					'type' => 'string',
 					'default' => '/var/customers/webs/',
+					'plausibility_check_method' => 'checkPathConflicts',
 					'save_method' => 'storeSettingField',
 					),
 				'system_ipaddress' => array(
@@ -83,15 +84,6 @@ return array(
 					'plausibility_check_method' => 'checkMysqlAccessHost',
 					'save_method' => 'storeSettingMysqlAccessHost',
 					),
-				'system_realtime_port' => array(
-					'label' => $lng['serversettings']['system_realtime_port'],
-					'settinggroup' => 'system',
-					'varname' => 'realtime_port',
-					'type' => (function_exists('socket_create') ? 'int' : 'hidden'),
-					'int_max' => 65535,
-					'default' => 0,
-					'save_method' => 'storeSettingField',
-					),
 				'system_index_file_extension' => array(
 					'label' => $lng['serversettings']['index_file_extension'],
 					'settinggroup' => 'system',
