@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Panel
- * @version    $Id: customer_mysql.php 1142 2010-06-17 09:21:14Z d00p $
+ * @version    $Id: customer_mysql.php 1245 2010-08-10 09:21:07Z d00p $
  */
 
 define('AREA', 'customer');
@@ -194,11 +194,10 @@ elseif($page == 'mysqls')
 
 					if($sendinfomail == 1)
 					{
-						$pma = '';
+						$pma = $lng['admin']['notgiven'];
 						if($settings['panel']['phpmyadmin_url'] != '')
 						{
-							$r_arr = array('URI' => $settings['panel']['phpmyadmin_url']);
-							$pma = replace_variables($lng['customer']['mysql_add']['infomail_body']['pma'], $r_arr);
+							$pma = $settings['panel']['phpmyadmin_url'];
 						}
 
 						$replace_arr = array(
@@ -210,11 +209,15 @@ elseif($page == 'mysqls')
 							'PMA_URI' => $pma 
 						);
 						
-						$mail_body = replace_variables($lng['customer']['mysql_add']['infomail_body']['main'], $replace_arr);
-						
+						$def_language = $userinfo['def_language'];
+						$result = $db->query_first('SELECT `value` FROM `' . TABLE_PANEL_TEMPLATES . '` WHERE `adminid`=\'' . (int)$userinfo['adminid'] . '\' AND `language`=\'' . $db->escape($def_language) . '\' AND `templategroup`=\'mails\' AND `varname`=\'new_database_by_customer_subject\'');
+						$mail_subject = html_entity_decode(replace_variables((($result['value'] != '') ? $result['value'] : $lng['customer']['mysql_add']['infomail_subject']), $replace_arr));
+						$result = $db->query_first('SELECT `value` FROM `' . TABLE_PANEL_TEMPLATES . '` WHERE `adminid`=\'' . (int)$userinfo['adminid'] . '\' AND `language`=\'' . $db->escape($def_language) . '\' AND `templategroup`=\'mails\' AND `varname`=\'new_database_by_customer_mailbody\'');
+						$mail_body = html_entity_decode(replace_variables((($result['value'] != '') ? $result['value'] : $lng['customer']['mysql_add']['infomail_body']['main']), $replace_arr));
+
 						$_mailerror = false;
 						try {
-							$mail->Subject = $lng['customer']['mysql_add']['infomail_subject'];
+							$mail->Subject = $mail_subject;
 							$mail->AltBody = $mail_body;
 							$mail->MsgHTML(str_replace("\n", "<br />", $mail_body));
 							$mail->AddAddress($userinfo['email'], getCorrectUserSalutation($userinfo));
@@ -270,14 +273,14 @@ elseif($page == 'mysqls')
 			   && $_POST['send'] == 'send')
 			{
 				// Only change Password if it is set, do nothing if it is empty! -- PH 2004-11-29
-
 				$password = validate($_POST['mysql_password'], 'password');
-				$password = validatePassword($password);
 
 				if($password != '')
 				{
-					// Begin root-session
+					// validate password
+					$password = validatePassword($password);
 
+					// Begin root-session
 					$db_root = new db($sql_root[$result['dbserver']]['host'], $sql_root[$result['dbserver']]['user'], $sql_root[$result['dbserver']]['password'], '');
 					unset($db_root->password);
 					foreach(array_map('trim', explode(',', $settings['system']['mysql_access_host'])) as $mysql_access_host)
