@@ -12,7 +12,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Install
- * @version    $Id: update_0.9.inc.php 1321 2010-10-01 06:10:45Z d00p $
+ * @version    $Id: update_0.9.inc.php 1412 2010-10-25 11:22:29Z d00p $
  */
 
 if(isFroxlorVersion('0.9-r0'))
@@ -1096,3 +1096,156 @@ if(isFroxlorVersion('0.9.14-svn1'))
 
 	updateToVersion('0.9.13.1');
 }
+
+if(isFroxlorVersion('0.9.13.1'))
+{
+	showUpdateStep("Updating from 0.9.13.1 to 0.9.14-svn2", false);
+	
+	if($settings['ticket']['enabled'] == '1')
+	{
+		showUpdateStep("Setting INTERVAL for used-tickets cronjob");
+		setCycleOfCronjob(null, null, $settings['ticket']['reset_cycle'], null);
+		lastStepStatus(0);
+	}
+	updateToVersion('0.9.14-svn2');
+}
+
+if(isFroxlorVersion('0.9.14-svn2'))
+{
+	showUpdateStep("Updating from 0.9.14-svn2 to 0.9.14-svn3", false);
+
+	$update_awstats_icons = isset($_POST['update_awstats_icons']) ? makeCorrectDir($_POST['update_awstats_icons']) : $settings['system']['awstats_icons'];	
+
+	showUpdateStep("Adding AWStats icons path to the settings");
+	$db->query("INSERT INTO `" . TABLE_PANEL_SETTINGS . "` (`settinggroup`, `varname`, `value`) VALUES ('system', 'awstats_icons', '".$db->escape($update_awstats_icons)."');");
+	lastStepStatus(0);
+
+	updateToVersion('0.9.14-svn3');
+}
+
+if(isFroxlorVersion('0.9.14-svn3'))
+{
+	showUpdateStep("Updating from 0.9.14-svn3 to 0.9.14-svn4", false);
+
+	$update_ssl_cert_chainfile = isset($_POST['update_ssl_cert_chainfile']) ? $_POST['update_ssl_cert_chainfile'] : '';	
+
+	if($update_ssl_cert_chainfile != '')
+	{
+		$update_ssl_cert_chainfile = makeCorrectFile($update_ssl_cert_chainfile);
+	}
+
+	showUpdateStep("Adding SSLCertificateChainFile to the settings");
+	$db->query("INSERT INTO `" . TABLE_PANEL_SETTINGS . "` (`settinggroup`, `varname`, `value`) VALUES ('system', 'ssl_cert_chainfile', '".$db->escape($update_ssl_cert_chainfile)."');");
+	lastStepStatus(0);
+
+	showUpdateStep("Adding new field to IPs and ports for SSLCertificateChainFile");
+	$db->query("ALTER TABLE `".TABLE_PANEL_IPSANDPORTS."` ADD `ssl_cert_chainfile` varchar(255) NOT NULL AFTER `default_vhostconf_domain`;");
+	lastStepStatus(0);
+
+	updateToVersion('0.9.14-svn4');
+}
+
+if(isFroxlorVersion('0.9.14-svn4'))
+{
+	showUpdateStep("Updating from 0.9.14-svn4 to 0.9.14-svn5", false);
+
+	showUpdateStep("Adding docroot-field to IPs and ports for custom-docroot settings");
+	$db->query("ALTER TABLE `".TABLE_PANEL_IPSANDPORTS."` ADD `docroot` varchar(255) NOT NULL default '' AFTER `ssl_cert_chainfile`;");
+	lastStepStatus(0);
+
+	updateToVersion('0.9.14-svn5');
+}
+
+if(isFroxlorVersion('0.9.14-svn5'))
+{
+	showUpdateStep("Updating from 0.9.14-svn5 to 0.9.14-svn6", false);
+
+	$update_allow_domain_login = isset($_POST['update_allow_domain_login']) ? (int)$_POST['update_allow_domain_login'] : '0';
+
+	showUpdateStep("Adding domain-login switch to the settings");
+	$db->query("INSERT INTO `" . TABLE_PANEL_SETTINGS . "` (`settinggroup`, `varname`, `value`) VALUES ('login', 'domain_login', '".(int)$update_allow_domain_login."');");
+	lastStepStatus(0);
+
+	updateToVersion('0.9.14-svn6');
+}
+
+/*
+ * revert database changes we did for multiserver-support
+ * before branching - sorry guys :/
+ */
+if(isFroxlorVersion('0.9.14-svn9'))
+{
+	showUpdateStep("Reverting multiserver-patches (svn)", false);
+
+	$update_allow_domain_login = isset($_POST['update_allow_domain_login']) ? (int)$_POST['update_allow_domain_login'] : '0';
+
+	showUpdateStep("Reverting database table-changes");
+	$db->query("ALTER TABLE `".TABLE_PANEL_SETTINGS."` DROP `sid`;");
+
+	showUpdateStep(".");
+	$db->query("ALTER TABLE `".TABLE_PANEL_CUSTOMERS."` DROP `sid`;");
+
+	showUpdateStep(".");
+	$db->query("ALTER TABLE `".TABLE_MAIL_VIRTUAL."` DROP `sid`;");
+
+	showUpdateStep(".");
+	$db->query("ALTER TABLE `".TABLE_FTP_USERS."` DROP `sid`;");
+
+	showUpdateStep(".");
+	$db->query("ALTER TABLE `".TABLE_PANEL_TASKS."` DROP `sid`;");
+
+	showUpdateStep(".");
+	$db->query("ALTER TABLE `".TABLE_APS_TASKS."` DROP `sid`;");
+
+	showUpdateStep(".");
+	$db->query("ALTER TABLE `".TABLE_PANEL_LOG."` DROP `sid`;");
+
+	showUpdateStep(".");
+	$db->query("ALTER TABLE `".TABLE_PANEL_PHPCONFIGS."` DROP `sid`;");
+	lastStepStatus(0);
+
+	showUpdateStep("Removing froxlor-clients table");
+	$db->query("DROP TABLE IF EXISTS `froxlor_clients`");
+	lastStepStatus(0);
+
+	updateToVersion('0.9.14-svn10');
+}
+
+if(isFroxlorVersion('0.9.14-svn6'))
+{
+	showUpdateStep("Updating from 0.9.14-svn6 to 0.9.14-svn10", false);
+
+	// remove deprecated realtime-feature
+	showUpdateStep("Removing realtime-feature (deprecated)");
+	$db->query("DELETE FROM `" . TABLE_PANEL_SETTINGS . "` WHERE `settinggroup` = 'system' AND `varname` = 'realtime_port';");
+	lastStepStatus(0);
+
+	// remove deprecated panel_navigation
+	showUpdateStep("Removing table `panel_navigation` (deprecated)");
+	$db->query("DROP TABLE IF EXISTS `panel_navigation`;");
+	lastStepStatus(0);
+
+	// remove deprecated panel_cronscript
+	showUpdateStep("Removing table `panel_cronscript` (deprecated)");
+	$db->query("DROP TABLE IF EXISTS `panel_cronscript`;");
+	lastStepStatus(0);
+
+	// make ticket-system ipv6 compatible
+	showUpdateStep("Altering IP field in panel_tickets (IPv6 compatibility)");
+	$db->query("ALTER TABLE `" . TABLE_PANEL_TICKETS . "` MODIFY `ip` varchar(39) NOT NULL default '';");
+	lastStepStatus(0);
+
+	showUpdateStep("Removing deprecated legacy-cronjob from database");
+	$db->query("DELETE FROM `".TABLE_PANEL_CRONRUNS."` WHERE `cronfile` ='cron_legacy.php';");
+	lastStepStatus(0);
+
+	updateToVersion('0.9.14-svn10');
+}
+
+if(isFroxlorVersion('0.9.14-svn10'))
+{
+	showUpdateStep("Updating from 0.9.14-svn10 to 0.9.14 final");
+	lastStepStatus(0);
+
+	updateToVersion('0.9.14');
+}
