@@ -12,7 +12,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Language
- * @version    $Id: preconfig_0.9.inc.php 1321 2010-10-01 06:10:45Z d00p $
+ * @version    $Id: preconfig_0.9.inc.php 1389 2010-10-23 10:37:43Z d00p $
  */
 
 /**
@@ -310,4 +310,45 @@ function parseAndOutputPreconfig(&$has_preconfig, &$return, $current_version)
 			eval("\$return.=\"" . getTemplate("update/preconfigitem") . "\";");
 		}
 	}
+
+	if(versionInUpdate($current_version, '0.9.14-svn3'))
+	{
+		if((int)$settings['system']['awstats_enabled'] == 1)
+		{
+			$has_preconfig = true;
+			$description = 'To have icons in AWStats statistic-pages please enter the path to AWStats icons folder.';
+			$question = '<strong>Path to AWSTats icons folder:</strong>&nbsp;';
+			$question.= '<input type="text" class="text" name="update_awstats_icons" value="'.$settings['system']['awstats_icons'].'" />';
+			eval("\$return.=\"" . getTemplate("update/preconfigitem") . "\";");
+		}
+	}
+
+	if(versionInUpdate($current_version, '0.9.14-svn4'))
+	{
+		if((int)$settings['system']['use_ssl'] == 1)
+		{
+			$has_preconfig = true;
+			$description = 'Froxlor now has the possibility to set \'SSLCertificateChainFile\' for the apache webserver.';
+			$question = '<strong>Enter filename (leave empty for none):</strong>&nbsp;';
+			$question.= '<input type="text" class="text" name="update_ssl_cert_chainfile" value="'.$settings['system']['ssl_cert_chainfile'].'" />';
+			eval("\$return.=\"" . getTemplate("update/preconfigitem") . "\";");
+		}
+	}
+
+	if(versionInUpdate($current_version, '0.9.14-svn6'))
+	{
+		$has_preconfig = true;
+		$description = 'You can now allow customers to use any of their domains as username for the login.';
+		$question = '<strong>Do you want to enable domain-login for all customers?:</strong>&nbsp;';
+		$question.= makeyesno('update_allow_domain_login', '1', '0', '0');
+		eval("\$return.=\"" . getTemplate("update/preconfigitem") . "\";");
+	}
+
+	if(versionInUpdate($current_version, '0.9.14-svn10'))
+	{       
+		$has_preconfig = true;
+		$description = '<strong>This update removes the unsupported real-time option. Additionally the deprecated tables for navigation and cronscripts are removed, any modules using these tables need to be updated to the new structure!</strong>'; 
+		$question = '';
+		eval("\$return.=\"" . getTemplate("update/preconfigitem") . "\";");
+	}
 }
