@@ -17,7 +17,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    APS
- * @version    $Id: class.ApsInstaller.php 1087 2010-06-14 08:09:17Z d00p $
+ * @version    $Id: class.ApsInstaller.php 1169 2010-06-24 08:11:43Z d00p $
  * @todo		logging
  *				run with user uid/gid
  *				folder truncation/tar all files
@@ -219,11 +219,7 @@ class ApsInstaller extends ApsParser
 		}
 		elseif($Task == TASK_REMOVE)
 		{
-			//FIXME cleanup installation
-			//remove files from: $this->RealPath . $this->DomainPath . '/'
-			//remove permissions
-			//drop database
-
+			// check for database
 			if ($this->aps_version == '1.0')
 			{
 				// the good ole way
@@ -240,7 +236,7 @@ class ApsInstaller extends ApsParser
 
 			if($XmlDb->db->id)
 			{
-				//database management
+				//drop database permissions
 
 				$Database = 'web' . $Row['CustomerID'] . 'aps' . $Row['InstanceID'];
 				foreach(array_map('trim', explode(',', $this->Hosts)) as $DatabaseHost)
@@ -250,8 +246,15 @@ class ApsInstaller extends ApsParser
 					$this->db_root->query('DELETE FROM `mysql`.`user` WHERE `User` = "' . $this->db->escape($Database) . '" AND `Host` = "' . $this->db->escape($DatabaseHost) . '"');
 				}
 
+				//drop database
 				$this->db_root->query('DROP DATABASE IF EXISTS `' . $this->db->escape($Database) . '`');
 				$this->db_root->query('FLUSH PRIVILEGES');
+
+				/*
+				 * remove database from customer-mysql overview, #272
+				 */
+				$this->db->query('DELETE FROM `' . TABLE_PANEL_DATABASES . '` WHERE `customerid`="' . (int)$Row['CustomerID'] . '" AND `databasename`="' . $this->db->escape($Database) . '" AND `apsdb`="1"');
+				$result = $this->db->query('UPDATE `' . TABLE_PANEL_CUSTOMERS . '` SET `mysqls_used`=`mysqls_used`-1 WHERE `customerid`="' . (int)$Row['CustomerID'] . '"');
 			}
 
 			//remove task & delete package instance + settings
@@ -259,6 +262,20 @@ class ApsInstaller extends ApsParser
 			$this->db->query('DELETE FROM `' . TABLE_APS_TASKS . '` WHERE `Task` = ' . TASK_REMOVE . ' AND `InstanceID` = ' . $this->db->escape($Row['InstanceID']));
 			$this->db->query('DELETE FROM `' . TABLE_APS_INSTANCES . '` WHERE `ID` = ' . $this->db->escape($Row['InstanceID']));
 			$this->db->query('DELETE FROM `' . TABLE_APS_SETTINGS . '` WHERE `InstanceID` = ' . $this->db->escape($Row['InstanceID']));
+
+			//remove data,  #273
+			if($this->DomainPath != '' && $this->DomainPath != '/') {
+				self::UnlinkRecursive($this->RealPath . $this->DomainPath . '/');
+			} else {
+				// save awstats/webalizer folder if it's the docroot
+				self::UnlinkRecursive($this->RealPath . $this->DomainPath . '/', true);
+				// place standard-index file
+				$loginname = getLoginNameByUid($Row['CustomerID']);
+				if($loginname !== false)
+				{
+					storeDefaultIndex($loginname, $this->RealPath . $this->DomainPath . '/');
+				}
+			}
 		}
 	}
 
@@ -473,8 +490,6 @@ class ApsInstaller extends ApsParser
 
 	private function PrepareDatabase($Xml, $Row, $Task)
 	{
-		global $db_root;
-
 		$XmlDb = $Xml->requirements->children('http://apstandard.com/ns/1/db');
 
 		if ($this->aps_version == '1.0')
@@ -511,6 +526,13 @@ class ApsInstaller extends ApsParser
 				}
 
 				$this->db_root->query('FLUSH PRIVILEGES');
+
+				/*
+				 * add database to customers databases, #272
+				 */
+				$databasedescription = $Xml->name.' '.$Xml->version.' (Release ' . $Xml->release . ')'; 
+				$result = $this->db->query('INSERT INTO `' . TABLE_PANEL_DATABASES . '` (`customerid`, `databasename`, `description`, `dbserver`, `apsdb`) VALUES ("' . (int)$Row['CustomerID'] . '", "' . $this->db->escape($NewDatabase) . '", "' . $this->db->escape($databasedescription) . '", "0", "1")');
+				$result = $this->db->query('UPDATE `' . TABLE_PANEL_CUSTOMERS . '` SET `mysqls_used`=`mysqls_used`+1 WHERE `customerid`="' . (int)$Row['CustomerID'] . '"');	
 			}
 
 			//get first mysql access host
@@ -631,5 +653,3 @@ class ApsInstaller extends ApsParser
 		return false;
 	}
 }
-
-?>
\ No newline at end of file
