@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Logger
- * @version    $Id: class.ticket.php 1318 2010-09-30 12:53:34Z d00p $
+ * @version    $Id: class.ticket.php 1329 2010-10-10 08:20:32Z d00p $
  * @link       http://www.nutime.de/
  *
  * Support Tickets - Tickets-Class
@@ -88,7 +88,10 @@ class ticket
 
 		// initialize purifier
 		require_once dirname(dirname(__FILE__)).'/htmlpurifier/library/HTMLPurifier.auto.php';
-		$this->_purifier = new HTMLPurifier();
+		$config = HTMLPurifier_Config::createDefault();
+		$config->set('Core.Encoding', 'ISO-8859-1'); // for now
+		$config->set('HTML.Doctype', 'XHTML 1.0 Transitional');
+		$this->_purifier = new HTMLPurifier($config);
 
 		// initialize data array
 
