@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Configfiles
- * @version    $Id: gentoo.inc.php 1277 2010-09-13 06:11:25Z d00p $
+ * @version    $Id: gentoo.inc.php 1396 2010-10-24 08:59:00Z d00p $
  */
 
 return Array(
@@ -181,6 +181,7 @@ return Array(
 							'postmap /etc/postfix/mx_access'
 						),
 						'restart' => Array(
+							'newaliases',
 							'/etc/init.d/postfix restart'
 						)
 					),
@@ -336,18 +337,6 @@ milter_default_action = accept" >> /etc/postfix/main.cf'
 							'/etc/init.d/vixie-cron restart'
 						)
 					),
-					'xinetd' => Array(
-						'label' => 'xinet.d (froxlor updates in realtime)',
-						'commands' => Array(
-							'emerge -av xinetd'
-						),
-						'files' => Array(
-							'etc_xinetd.d_froxlor' => '/etc/xinetd.d/froxlor'
-						),
-						'restart' => Array(
-							'/etc/init.d/xinetd restart'
-						)
-					),
 					'awstats' => Array(
 						'label' => 'Awstats',
 						'commands' => Array(
