@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Lib
- * @version    $Id: configfiles_index.inc.php 699 2010-03-29 12:06:50Z d00p $
+ * @version    $Id: configfiles_index.inc.php 947 2010-05-17 09:24:23Z Dessa $
  */
 
 $configcommand = array();
@@ -45,6 +45,6 @@ else
 
 $cfgPath = 'lib/configfiles/';
 $configfiles = Array();
-$configfiles = array_merge(include $cfgPath . 'lenny.inc.php', include $cfgPath . 'etch.inc.php', include $cfgPath . 'hardy.inc.php', include $cfgPath . 'gentoo.inc.php', include $cfgPath . 'suse10.inc.php', include $cfgPath . 'freebsd.inc.php');
+$configfiles = array_merge(include $cfgPath . 'lenny.inc.php', include $cfgPath . 'etch.inc.php', include $cfgPath . 'hardy.inc.php', include $cfgPath . 'lucid.inc.php', include $cfgPath . 'gentoo.inc.php', include $cfgPath . 'suse10.inc.php', include $cfgPath . 'freebsd.inc.php');
 
 ?>
\ No newline at end of file
