@@ -14,38 +14,28 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Functions
- * @version    $Id: function.ask_yesno.php 1196 2010-07-24 17:26:24Z d00p $
+ * @version    $Id: function.ask_yesno.php 1289 2010-09-20 06:07:54Z d00p $
  */
 
 /**
  * Prints Question on screen
  *
- * @param string The question
- * @param string File which will be called with POST if user clicks yes
- * @param array Values which will be given to $yesfile. Format: array(variable1=>value1, variable2=>value2, variable3=>value3)
- * @param string Name of the target eg Domain or eMail address etc.
+ * @param string $text       The question
+ * @param string $yesfile    File which will be called with POST if user clicks yes
+ * @param array  $params     Values which will be given to $yesfile. Format: array(variable1=>value1, variable2=>value2, variable3=>value3)
+ * @param string $targetname Name of the target eg Domain or eMail address etc.
+ * @param int    $back_nr    Number of steps to go back when "No" is pressed
+ * 
  * @author Florian Lippert <flo@syscp.org>
+ * @author Froxlor team <team@froxlor.org> (2010-)
+ * 
+ * @return string outputs parsed question_yesno template
  */
 
-function ask_yesno($text, $yesfile, $params = array(), $targetname = '')
+function ask_yesno($text, $yesfile, $params = array(), $targetname = '', $back_nr = 1)
 {
 	global $userinfo, $db, $s, $header, $footer, $lng;
 
-	/*
-		// For compatibility reasons (if $params contains a string like "field1=value1;field2=value2") this will convert it into a usable array
-		if(!is_array($params))
-		{
-			$params_tmp=explode(';',$params);
-			unset($params);
-			$params=array();
-			while(list(,$param_tmp)=each($params_tmp))
-			{
-				$param_tmp=explode('=',$param_tmp);
-				$params[$param_tmp[0]]=$param_tmp[1];
-			}
-		}
-*/
-
 	$hiddenparams = '';
 
 	if(is_array($params))
