@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Functions
- * @version    $Id: function.validateDomain.php 833 2010-04-20 21:35:30Z d00p $
+ * @version    $Id: function.validateDomain.php 889 2010-05-04 09:54:10Z d00p $
  */
 
 /**
@@ -39,22 +39,13 @@ function validateDomain($domainname)
 
 	// there is a bug in php 5.2.13 - 5.3.2 which
 	// lets filter_var fail if the domain has
-	// a dash (-) in it. #
-	if(version_compare("5.2.13", PHP_VERSION, "=")
-		|| version_compare("5.3.2", PHP_VERSION, "="))
-	{
-		$pattern = '/^http:\/\/([a-z0-9]([a-z0-9\-]{0,61}[a-z0-9])?\.)+[a-z]{2,6}$/i';
-		if(preg_match($pattern, $domainname_tmp))
-		{	
-			return $domainname;
-		}
-	}
-	else
-	{
-		if(filter_var($domainname_tmp, FILTER_VALIDATE_URL) !== false && filter_var($domainname_tmp, FILTER_VALIDATE_URL, FILTER_FLAG_PATH_REQUIRED) === false && filter_var($domainname_tmp, FILTER_VALIDATE_URL, FILTER_FLAG_QUERY_REQUIRED) === false)
-		{
-			return $domainname;
-		}
+	// a dash (-) in it. As the PHP_VERSION constant
+	// gives also patch-brandings, e.g. '5.3.2-pl0-gentoo'
+	// we just always use our regex
+	$pattern = '/^http:\/\/([a-z0-9]([a-z0-9\-]{0,61}[a-z0-9])?\.)+[a-z]{2,6}$/i';
+	if(preg_match($pattern, $domainname_tmp))
+	{	
+		return $domainname;
 	}
 	return false;
 }
