@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Functions
- * @version    $Id: function.validateUrl.php 891 2010-05-04 10:31:25Z d00p $
+ * @version    $Id: function.validateUrl.php 1407 2010-10-25 06:45:15Z d00p $
  */
 
 /**
@@ -39,7 +39,7 @@ function validateUrl($url)
 	// needs converting
 	$url = $idna_convert->encode($url);
 
-	$pattern = "/^https?:\/\/[a-zA-Z0-9\-\.]+\.[a-zA-Z]{2,3}(\/\S*)?$/i";
+	$pattern = "/^https?:\/\/[a-zA-Z0-9\-\.]+\.[a-zA-Z]{2,4}(\:[0-9]+)?\/?(.+)?$/i";
 	if(preg_match($pattern, $url))
 	{
 		return true;
