@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    System
- * @version    $Id: init.php 1191 2010-07-22 05:28:21Z d00p $
+ * @version    $Id: init.php 1281 2010-09-17 10:33:58Z d00p $
  */
 
 // prevent Froxlor pages from being cached
@@ -120,6 +120,15 @@ if(!isset($need_root_db_sql_data) || $need_root_db_sql_data !== true)
 
 $idna_convert = new idna_convert_wrapper();
 
+/**
+ * disable magic_quotes_runtime if enabled
+ */
+if(get_magic_quotes_runtime())
+{
+	//Deactivate
+	set_magic_quotes_runtime(false);
+}
+
 /**
  * Reverse magic_quotes_gpc=on to have clean GPC data again
  */
