@@ -17,7 +17,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Cron
- * @version    $Id: cron_autoresponder.php 1273 2010-09-07 10:56:58Z d00p $
+ * @version    $Id: cron_autoresponder.php 1319 2010-10-01 05:10:01Z d00p $
  * @todo	   skip mail parsing after x bytes for large mails
  */
 
@@ -138,7 +138,7 @@ if($db->num_rows($result) > 0)
 						$to = $match[2];
 					}
 					elseif(!strlen($to)
-					       && preg_match("/To:\s+(.*@.*)$/", $line, $match)
+					       && preg_match("/^To:\s+(.*@.*)$/", $line, $match) 
 					) {
 						$to = $match[1];
 					}
