@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Cron
- * @version    $Id: cron_tasks.inc.dns.10.bind.php 829 2010-04-20 06:22:11Z d00p $
+ * @version    $Id: cron_tasks.inc.dns.10.bind.php 1045 2010-06-02 10:08:01Z d00p $
  */
 
 /*
@@ -225,6 +225,17 @@ class bind
 			{
 				$zonefile.= '@	IN	MX	' . trim($mxserver) . "\n";
 			}
+			
+			if($this->settings['system']['dns_createmailentry'] == '1')
+			{
+				$zonefile.= 'mail	IN	' . $ip_a_record . "\n";
+				if($domain['iswildcarddomain'] != '1')
+				{
+					$zonefile.= 'imap	IN	' . $ip_a_record . "\n";
+					$zonefile.= 'smtp	IN	' . $ip_a_record . "\n";
+					$zonefile.= 'pop3	IN	' . $ip_a_record . "\n";
+				}
+			}
 		}
 
 		/*
