@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Cron
- * @version    $Id: cron_tasks.inc.http.10.apache.php 1305 2010-09-24 17:16:33Z d00p $
+ * @version    $Id: cron_tasks.inc.http.10.apache.php 1367 2010-10-19 19:32:53Z d00p $
  */
 
 if(@php_sapi_name() != 'cli'
@@ -189,17 +189,26 @@ class apache
 			{
 				$this->virtualhosts_data[$vhosts_filename].= '<VirtualHost ' . $ipport . '>' . "\n";
 
-				/**
-				 * add 'real'-vhost content here, like doc-root :)
-				 */
-				if($this->settings['system']['froxlordirectlyviahostname'])
+				if($row_ipsandports['docroot'] == '')
 				{
-					$mypath = makeCorrectDir(dirname(dirname(dirname(__FILE__))));
+					/**
+					 * add 'real'-vhost content here, like doc-root :)
+					 */
+					if($this->settings['system']['froxlordirectlyviahostname'])
+					{
+						$mypath = makeCorrectDir(dirname(dirname(dirname(__FILE__))));
+					}
+					else 
+					{
+						$mypath = makeCorrectDir(dirname(dirname(dirname(dirname(__FILE__)))));
+					}
 				}
-				else 
+				else
 				{
-					$mypath = makeCorrectDir(dirname(dirname(dirname(dirname(__FILE__)))));
+					// user-defined docroot, #417
+					$mypath = makeCorrectDir($row_ipsandports['docroot']);
 				}
+
 				$this->virtualhosts_data[$vhosts_filename].= 'DocumentRoot "'.$mypath.'"'."\n";
 				
 				if($row_ipsandports['vhostcontainer_servername_statement'] == '1')
@@ -268,6 +277,12 @@ class apache
 						$row_ipsandports['ssl_ca_file'] = $this->settings['system']['ssl_ca_file'];
 					}
 
+					// #418
+					if($row_ipsandports['ssl_cert_chainfile'] == '')
+					{
+						$row_ipsandports['ssl_cert_chainfile'] = $this->settings['system']['ssl_cert_chainfile'];
+					}
+
 					if($row_ipsandports['ssl_cert_file'] != '')
 					{
 						$this->virtualhosts_data[$vhosts_filename].= ' SSLEngine On' . "\n";
@@ -282,6 +297,12 @@ class apache
 						{
 							$this->virtualhosts_data[$vhosts_filename].= ' SSLCACertificateFile ' . makeCorrectFile($row_ipsandports['ssl_ca_file']) . "\n";
 						}
+
+						// #418
+						if($row_ipsandports['ssl_cert_chainfile'] != '')
+						{
+							$this->virtualhosts_data[$vhosts_filename].= '  SSLCertificateChainFile ' . makeCorrectFile($row_ipsandports['ssl_cert_chainfile']) . "\n";
+						}
 					}
 				}
 
@@ -449,6 +470,7 @@ class apache
 				if($this->settings['system']['awstats_enabled'] == '1')
 				{
 					$stats_text.= '  Alias /awstats "' . makeCorrectFile($domain['customerroot'] . '/awstats/' . $domain['domain']) . '"' . "\n";
+					$stats_text.= '  Alias /awstats-icon "' . makeCorrectDir($this->settings['system']['awstats_icons']) . '"' . "\n";
 				}
 				else
 				{
@@ -460,6 +482,7 @@ class apache
 				if($this->settings['system']['awstats_enabled'] == '1')
 				{
 					$stats_text.= '  Alias /awstats "' . makeCorrectFile($domain['customerroot'] . '/awstats/' . $domain['parentdomain']) . '"' . "\n";
+					$stats_text.= '  Alias /awstats-icon "' . makeCorrectDir($this->settings['system']['awstats_icons']) . '"' . "\n";
 				}
 				else
 				{
@@ -474,6 +497,7 @@ class apache
 				if($this->settings['system']['awstats_enabled'] == '1')
 				{
 					$stats_text.= '  Alias /awstats "' . makeCorrectFile($domain['customerroot'] . '/awstats/' . $domain['domain']) . '"' . "\n";
+					$stats_text.= '  Alias /awstats-icon "' . makeCorrectDir($this->settings['system']['awstats_icons']) . '"' . "\n";
 				} 
 				else
 				{
@@ -587,7 +611,13 @@ class apache
 	
 				// After inserting the AWStats information, 
 				// be sure to build the awstats conf file as well
-				createAWStatsConf($this->settings['system']['logfiles_directory'] . $domain['loginname'] . $speciallogfile . '-access.log', $domain['domain'], $alias . $server_alias, $domain['customerroot']);
+				// and chown it using $awstats_params, #258
+				$awstats_param = array(
+					'loginname' => $domain['loginname'],
+					'guid' => $domain['guid'],
+					'documentroot' => $domain['documentroot']
+				);
+				createAWStatsConf($this->settings['system']['logfiles_directory'] . $domain['loginname'] . $speciallogfile . '-access.log', $domain['domain'], $alias . $server_alias, $domain['customerroot'], $awstats_params);
 			}
 		}
 
@@ -656,6 +686,8 @@ class apache
 		$domain['ssl_cert_file'] = $ipandport['ssl_cert_file'];
 		$domain['ssl_key_file'] = $ipandport['ssl_key_file'];
 		$domain['ssl_ca_file'] = $ipandport['ssl_ca_file'];
+		// #418
+		$domain['ssl_cert_chainfile'] = $ipandport['ssl_cert_chainfile'];
 
 		if(filter_var($domain['ip'], FILTER_VALIDATE_IP, FILTER_FLAG_IPV6))
 		{
@@ -702,6 +734,12 @@ class apache
 					$domain['ssl_ca_file'] = $this->settings['system']['ssl_ca_file'];
 				}
 
+				// #418
+				if($domain['ssl_cert_chainfile'] == '')
+				{
+					$domain['ssl_cert_chainfile'] = $this->settings['system']['ssl_cert_chainfile'];
+				}
+
 				if($domain['ssl_cert_file'] != '')
 				{
 					$vhost_content.= '  SSLEngine On' . "\n";
@@ -716,6 +754,12 @@ class apache
 					{
 						$vhost_content.= '  SSLCACertificateFile ' . makeCorrectFile($domain['ssl_ca_file']) . "\n";
 					}
+
+					// #418
+					if($domain['ssl_cert_chainfile'] != '')
+					{
+						$vhost_content.= '  SSLCertificateChainFile ' . makeCorrectFile($domain['ssl_cert_chainfile']) . "\n";
+					}
 				}
 			}
 
@@ -1080,9 +1124,15 @@ class apache
 			if(!isConfigDir($this->settings['system']['apacheconf_vhost']))
 			{
 				// Save one big file
-
 				$vhosts_file = '';
 
+				// sort by filename so the order is:
+				// 1. subdomains                  20
+				// 2. subdomains as main-domains  21
+				// 3. main-domains                22
+				// #437
+				ksort($this->virtualhosts_data);
+
 				foreach($this->virtualhosts_data as $vhosts_filename => $vhost_content)
 				{
 					$vhosts_file.= $vhost_content . "\n\n";
