@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Cron
- * @version    $Id: cron_tasks.inc.http.20.lighttpd.php 1305 2010-09-24 17:16:33Z d00p $
+ * @version    $Id: cron_tasks.inc.http.20.lighttpd.php 1367 2010-10-19 19:32:53Z d00p $
  */
 
 /*
@@ -107,14 +107,23 @@ class lighttpd
 				$this->lighttpd_data[$vhost_filename].= '# Froxlor default vhost' . "\n";
 				$this->lighttpd_data[$vhost_filename].= '$HTTP["host"] =~ "^(?:www\.|)' . $myhost . '$" {' . "\n";
 
-				if($this->settings['system']['froxlordirectlyviahostname'])
+				if($row_ipsandports['docroot'] == '')
 				{
-					$mypath = makeCorrectDir(dirname(dirname(dirname(__FILE__))));
+					if($this->settings['system']['froxlordirectlyviahostname'])
+					{
+						$mypath = makeCorrectDir(dirname(dirname(dirname(__FILE__))));
+					}
+					else 
+					{
+						$mypath = makeCorrectDir(dirname(dirname(dirname(dirname(__FILE__)))));
+					}
 				}
-				else 
+				else
 				{
-					$mypath = makeCorrectDir(dirname(dirname(dirname(dirname(__FILE__)))));
+					// user-defined docroot, #417
+					$mypath = makeCorrectDir($row_ipsandports['docroot']);
 				}
+
 				$this->lighttpd_data[$vhost_filename].= '  server.document-root = "'.$mypath.'"'."\n";
 
 				/**
@@ -136,8 +145,26 @@ class lighttpd
 	
 			if($row_ipsandports['ssl'] == '1')
 			{
-				$this->lighttpd_data[$vhost_filename].= 'ssl.engine = "enable"' . "\n";
-				$this->lighttpd_data[$vhost_filename].= 'ssl.pemfile = "' . $row_ipsandports['ssl_cert_file'] . '"' . "\n";
+				if($row_ipsandports['ssl_cert_file'] == '')
+				{
+					$row_ipsandports['ssl_cert_file'] = $this->settings['system']['ssl_cert_file'];
+				}
+
+				if($row_ipsandports['ssl_ca_file'] == '')
+				{
+					$row_ipsandports['ssl_ca_file'] = $this->settings['system']['ssl_ca_file'];
+				}
+				
+				if($row_ipsandports['ssl_cert_file'] != '')
+				{
+					$this->lighttpd_data[$vhost_filename].= 'ssl.engine = "enable"' . "\n";
+					$this->lighttpd_data[$vhost_filename].= 'ssl.pemfile = "' . makeCorrectFile($row_ipsandports['ssl_cert_file']) . '"' . "\n";
+					
+					if($row_ipsandports['ssl_ca_file'] != '')
+					{
+						$this->lighttpd_data[$vhost_filename].= 'ssl.ca-file = "' . makeCorrectFile($row_ipsandports['ssl_ca_file']) . '"' . "\n";
+					}
+				}
 			}
 
 			/**
@@ -313,12 +340,6 @@ class lighttpd
 			{
 				$this->lighttpd_data[$vhost_filename] = '';
 			}
-					
-			$query = "SELECT * FROM " . TABLE_PANEL_IPSANDPORTS . " WHERE `id`='" . $domain['ipandport'] . "'";
-			$ipandport = $this->db->query_first($query);
-			$domain['ip'] = $ipandport['ip'];
-			$domain['port'] = $ipandport['port'];
-			$domain['ssl_cert_file'] = $ipandport['ssl_cert_file'];
 
 			if((!empty($this->lighttpd_data[$vhost_filename])
 				&& !is_dir($this->settings['system']['apacheconf_vhost']))
@@ -364,6 +385,7 @@ class lighttpd
 		$domain['ip'] = $ipandport['ip'];
 		$domain['port'] = $ipandport['port'];
 		$domain['ssl_cert_file'] = $ipandport['ssl_cert_file'];
+		$domain['ssl_ca_file'] = $ipandport['ssl_ca_file'];
 
 		if(filter_var($domain['ip'], FILTER_VALIDATE_IP, FILTER_FLAG_IPV6))
 		{
@@ -400,6 +422,7 @@ class lighttpd
 				$vhost_content.= $this->composePhpOptions($domain);
 				$vhost_content.= $this->getStats($domain);
 				$vhost_content.= $this->getLogFiles($domain);
+				$vhost_content.= $this->getSslSettings($domain, $ssl_vhost);
 			}
 		}
 
@@ -411,6 +434,38 @@ class lighttpd
 		return $vhost_content;
 	}
 
+	protected function getSslSettings($domain, $ssl_vhost)
+	{
+		$ssl_settings = '';
+		
+		if($ssl_vhost === true
+			&& $domain['ssl'] == '1'
+			&& (int)$this->settings['system']['use_ssl'] == 1
+		) {
+			if($domain['ssl_cert_file'] == '')
+			{
+				$domain['ssl_cert_file'] = $this->settings['system']['ssl_cert_file'];
+			}
+
+			if($domain['ssl_ca_file'] == '')
+			{
+				$domain['ssl_ca_file'] = $this->settings['system']['ssl_ca_file'];
+			}
+			
+			if($domain['ssl_cert_file'] != '')
+			{
+				$ssl_settings.= 'ssl.engine = "enable"' . "\n";
+				$ssl_settings.= 'ssl.pemfile = "' . makeCorrectFile($domain['ssl_cert_file']) . '"' . "\n";
+				
+				if($domain['ssl_ca_file'] != '')
+				{
+					$ssl_settings.= 'ssl.ca-file = "' . makeCorrectFile($domain['ssl_ca_file']) . '"' . "\n";
+				}
+			}
+		}
+		return $ssl_settings;
+	}
+
 	protected function getLogFiles($domain)
 	{
 		$logfiles_text = '';
@@ -502,7 +557,13 @@ class lighttpd
 	
 				// After inserting the AWStats information, 
 				// be sure to build the awstats conf file as well
-				createAWStatsConf($this->settings['system']['logfiles_directory'] . $domain['loginname'] . $speciallogfile . '-access.log', $domain['domain'], $alias . $server_alias, $domain['customerroot']);
+				// and chown it using $awstats_params, #258
+				$awstats_param = array(
+					'loginname' => $domain['loginname'],
+					'guid' => $domain['guid'],
+					'documentroot' => $domain['documentroot']
+				);
+				createAWStatsConf($this->settings['system']['logfiles_directory'] . $domain['loginname'] . $speciallogfile . '-access.log', $domain['domain'], $alias . $server_alias, $domain['customerroot'], $awstats_param);
 			}
 		}
 
@@ -759,8 +820,8 @@ class lighttpd
 			{
 				if($this->settings['system']['awstats_enabled'] == '1')
 				{
-					// @TODO see if this is correct for awstats
 					$stats_text.= '  alias.url = ( "/awstats/" => "'.makeCorrectFile($domain['customerroot'] . '/awstats/' . $domain['domain']).'" )' . "\n";
+					$stats_text.= '  alias.url = ( "/awstats-icon" => "' . makeCorrectDir($this->settings['system']['awstats_icons']) . '" )' . "\n";
 				}
 				else
 				{
@@ -771,8 +832,8 @@ class lighttpd
 			{
 				if($this->settings['system']['awstats_enabled'] == '1')
 				{
-					// @TODO see if this is correct for awstats
 					$stats_text.= '  alias.url = ( "/awstats/" => "'.makeCorrectFile($domain['customerroot'] . '/awstats/' . $domain['parentdomain']).'" )' . "\n";
+					$stats_text.= '  alias.url = ( "/awstats-icon" => "' . makeCorrectDir($this->settings['system']['awstats_icons']) . '" )' . "\n";
 				}
 				else
 				{
@@ -787,6 +848,7 @@ class lighttpd
 				if($this->settings['system']['awstats_enabled'] == '1')
 				{
 					$stats_text.= '  alias.url = ( "/awstats/" => "'.makeCorrectFile($domain['customerroot'] . '/awstats/' . $domain['domain']).'" )' . "\n";
+					$stats_text.= '  alias.url = ( "/awstats-icon" => "' . makeCorrectDir($this->settings['system']['awstats_icons']) . '" )' . "\n";
 				} 
 				else
 				{
@@ -808,6 +870,13 @@ class lighttpd
 			// Save one big file
 			$vhosts_file = '';
 
+			// sort by filename so the order is:
+			// 1. subdomains
+			// 2. subdomains as main-domains
+			// 3. main-domains
+			// #437
+			ksort($this->lighttpd_data);
+
 			foreach($this->lighttpd_data as $vhosts_filename => $vhost_content)
 			{
 				$vhosts_file.= $vhost_content . "\n\n";
